@@ -24,6 +24,7 @@ from .protocol import (  # noqa: F401, isort: skip
     _000E,
     _0016,
     _0100,
+    _0150,
     _01D0,
     _01E9,
     _0404,
@@ -34,8 +35,11 @@ from .protocol import (  # noqa: F401, isort: skip
     _1060,
     _1081,
     _1090,
+    _1098,
     _10A0,
+    _10B0,
     _10E0,
+    _10E1,
     _1100,
     _1260,
     _1280,
@@ -50,6 +54,7 @@ from .protocol import (  # noqa: F401, isort: skip
     _1F09,
     _1F41,
     _1FC9,
+    _1FD0,
     _1FD4,
     _2249,
     _22C9,
@@ -60,6 +65,10 @@ from .protocol import (  # noqa: F401, isort: skip
     _2309,
     _2349,
     _2389,
+    _2400,
+    _2401,
+    _2410,
+    _2420,
     _2D49,
     _2E04,
     _30C9,
@@ -69,7 +78,11 @@ from .protocol import (  # noqa: F401, isort: skip
     _31D9,
     _31DA,
     _31E0,
+    _3200,
+    _3210,
     _3220,
+    _3221,
+    _3223,
     _3B00,
     _3EF0,
     _3EF1,
@@ -132,8 +145,8 @@ class Entity:
         self._gwy = gwy
         self.id = None
 
-        self._msgs = {}
-        self._msgz = {}
+        self._msgs = {}  # code, should be code/ctx? ?deprecate
+        self._msgz = {}  # code/verb/ctx, should be code/ctx/verb?
 
         self._qos_tx_count = 0  # the number of pkts Tx'd with no matching Rx
 
