@@ -9,57 +9,39 @@ from types import SimpleNamespace
 __dev_mode__ = False
 DEV_MODE = __dev_mode__
 
-USE_DEX = True
-
 
 def slug(string: str) -> str:
     return re.sub(r"[\W_]+", "_", string.lower())
 
 
 DEV_KLASS = SimpleNamespace(
+    DEV="DEV",  # Generic (promotable) device
+    #
+    HGI="HGI",  # Gateway interface (RF to USB), HGI80
+    RFG="RFG",  # RF gateway (RF to ethernet), RFG100
+    #
     BDR="BDR",  # Electrical relay
     CTL="CTL",  # Controller
-    C02="C02",  # HVAC C02 sensor
-    GEN="DEV",  # Generic device
     DHW="DHW",  # DHW sensor
     EXT="EXT",  # External weather sensor
-    FAN="FAN",  # HVAC fan, 31D[9A]: 20|29|30|37 (some, e.g. 29: only 31D9)
-    HGI="HGI",  # Gateway interface (RF to USB), HGI80
-    HUM="HUM",  # HVAC humidity sensor, 1260: 32
     OTB="OTB",  # OpenTherm bridge
     PRG="PRG",  # Programmer
-    RFG="RFG",  # RF gateway (RF to ethernet), RFG100
-    STA="STA",  # Thermostat
-    SWI="SWI",  # HVAC switch, 22F[13]: 02|06|20|32|39|42|49|59 (no 20: are both)
+    THM="THM",  # Thermostat - don't use STA
+    # DTS="DTS",  # Thermostat, DTS92(E)
+    # HCW="HCW",  # Thermostat, HCW80/82
+    # RND="RND",  # Thermostat, TR87RF
     TRV="TRV",  # Thermostatic radiator valve
     UFC="UFC",  # UFH controller
+    #
+    CO2="CO2",  # HVAC CO2 sensor
+    FAN="FAN",  # HVAC fan, 31D[9A]: 20|29|30|37 (some, e.g. 29: only 31D9)
+    HUM="HUM",  # HVAC humidity sensor, 1260: 32
+    SWI="SWI",  # HVAC switch, 22F[13]: 02|06|20|32|39|42|49|59 (no 20: are both)
+    #
     JIM="JIM",  # Jasper Interface Module (EIM?)
     JST="JST",  # Jasper Stat
 )
 
-DEVICE_CLASS_BY_TYPE = {
-    "01": DEV_KLASS.CTL,
-    "02": DEV_KLASS.UFC,
-    "04": DEV_KLASS.TRV,
-    "07": DEV_KLASS.DHW,
-    "08": DEV_KLASS.JIM,
-    "10": DEV_KLASS.OTB,
-    "13": DEV_KLASS.BDR,
-    "17": DEV_KLASS.EXT,
-    "18": DEV_KLASS.HGI,
-    "23": DEV_KLASS.PRG,
-    "31": DEV_KLASS.JST,
-    "34": DEV_KLASS.STA,
-}  # these are the 'reliable' (i.e. CH/DHW, not HVAC) type:klass pairs
-DEVICE_TYPE_BY_CLASS = {v: k for k, v in DEVICE_CLASS_BY_TYPE.items()}
-DEVICE_CLASS_BY_TYPE.update(
-    {
-        "00": DEV_KLASS.TRV,
-        "03": DEV_KLASS.STA,
-        "12": DEV_KLASS.STA,
-        "22": DEV_KLASS.STA,
-    }
-)
 
 HGI_DEVICE_ID = "18:000730"  # default type and address of HGI, 18:013393
 NON_DEVICE_ID = "--:------"
@@ -97,6 +79,7 @@ _10B0 = "10B0"
 _10E0 = "10E0"
 _10E1 = "10E1"
 _1100 = "1100"
+_11F0 = "11F0"
 _1260 = "1260"
 _1280 = "1280"
 _1290 = "1290"
@@ -110,6 +93,7 @@ _1300 = "1300"
 _1F09 = "1F09"
 _1F41 = "1F41"
 _1FC9 = "1FC9"
+_1FCA = "1FCA"
 _1FD0 = "1FD0"
 _1FD4 = "1FD4"
 _2249 = "2249"
@@ -127,6 +111,7 @@ _2410 = "2410"
 _2420 = "2420"
 _2D49 = "2D49"
 _2E04 = "2E04"
+_2E10 = "2E10"
 _30C9 = "30C9"
 _3120 = "3120"
 _313F = "313F"
@@ -157,51 +142,27 @@ DEFAULT_MAX_ZONES = 16 if DEV_MODE else 12
 # ATTR_DEV_REGEX_UFC = "ufh_controller_id"
 # ATTR_RELAY_DEVICE_ID = "relay_id"
 
-DEV_REGEX_ANY = r"^[0-9]{2}:[0-9]{6}$"
-DEV_REGEX_BDR = r"^13:[0-9]{6}$"
-DEV_REGEX_CTL = r"^(01|23):[0-9]{6}$"
-DEV_REGEX_DHW = r"^07:[0-9]{6}$"
-DEV_REGEX_HGI = r"^18:[0-9]{6}$"
-DEV_REGEX_HTG = r"^(10|13):[0-9]{6}$"
-DEV_REGEX_UFC = r"^02:[0-9]{6}$"
-DEV_REGEX_SEN = r"^('01'|'03'|'04'|'12'|'22'|'34'):[0-9]{6}$"
+_DEV_REGEX_ANY = r"^[0-9]{2}:[0-9]{6}$"
+_DEV_REGEX_BDR = r"^13:[0-9]{6}$"
+_DEV_REGEX_CTL = r"^(01|23):[0-9]{6}$"
+_DEV_REGEX_DHW = r"^07:[0-9]{6}$"
+_DEV_REGEX_HGI = r"^18:[0-9]{6}$"
+_DEV_REGEX_HTG = r"^(10|13):[0-9]{6}$"
+_DEV_REGEX_UFC = r"^02:[0-9]{6}$"
+_DEV_REGEX_SEN = r"^('01'|'03'|'04'|'12'|'22'|'34'):[0-9]{6}$"
 
 DEVICE_ID_REGEX = SimpleNamespace(
-    ANY=DEV_REGEX_ANY,
-    BDR=DEV_REGEX_BDR,
-    CTL=DEV_REGEX_CTL,
-    DHW=DEV_REGEX_DHW,
-    HGI=DEV_REGEX_HGI,
-    HTG=DEV_REGEX_HTG,
-    UFC=DEV_REGEX_UFC,
-    SEN=DEV_REGEX_SEN,
+    ANY=_DEV_REGEX_ANY,
+    BDR=_DEV_REGEX_BDR,
+    CTL=_DEV_REGEX_CTL,
+    DHW=_DEV_REGEX_DHW,
+    HGI=_DEV_REGEX_HGI,
+    HTG=_DEV_REGEX_HTG,
+    UFC=_DEV_REGEX_UFC,
+    SEN=_DEV_REGEX_SEN,
 )
 
-# # Packet codes (this dict is being deprecated) - check against ramses.py
-# CODE_SCHEMA = {
-#     _0001: {"uses_zone_idx": True},
-#     _01D0: {"uses_zone_idx": True},
-#     _01E9: {"uses_zone_idx": True},
-#     _0404: {"uses_zone_idx": True},
-#     _3EF1: {"uses_zone_idx": True},
-#     _0004: {"uses_zone_idx": True},
-#     _0008: {"uses_zone_idx": True},
-#     _0009: {"uses_zone_idx": True},
-#     _000A: {"uses_zone_idx": True},
-#     _1030: {"uses_zone_idx": True},
-#     _1060: {"uses_zone_idx": True},
-#     _12B0: {"uses_zone_idx": True},
-#     _1FC9: {"uses_zone_idx": True},
-#     _2249: {"uses_zone_idx": True},
-#     _2309: {"uses_zone_idx": True},
-#     _2349: {"uses_zone_idx": True},
-#     _30C9: {"uses_zone_idx": True},
-#     _3150: {"uses_zone_idx": True},
-# }
-
-# _MAY_USE_ZONE_IDX = [k for k, v in CODE_SCHEMA.items() if v.get("uses_zone_idx")]
-
-DEVICE_TABLE = {
+_OUT_DEVICE_TABLE = {
     # Honeywell evohome
     "01": {
         "type": "CTL",
@@ -253,13 +214,6 @@ DEVICE_TABLE = {
         "name": "Round Thermostat",
         "archetype": "T87RF",
     },
-    # Honeywell evohome TBD
-    "x1": {
-        "type": "HM8",
-        "name": "Mixing Valve",
-        "archetype": "HM80",
-    },  # TODO: ???
-    # Honeywell, non-evohome
     "17": {
         "type": "EXT",
         "name": "Outdoor Sensor?",
@@ -277,12 +231,6 @@ DEVICE_TABLE = {
     # Honeywell Jasper, HVAC?
     "08": {"type": "JIM", "name": "HVAC?"},  # Jasper equipment interface module
     "31": {"type": "JST", "name": "HVAC?"},  # Jasper Stat TXXX
-    # non-Honeywell, HVAC? (also, 30: is a Nuaire PIV)
-    "20": {"type": "VCE", "name": "HVAC?"},  # VCE-RF unit
-    "32": {"type": "VMS", "name": "HVAC?"},  # sensor/switch
-    "37": {"type": " 37", "name": "HVAC?"},  # VCE
-    "39": {"type": "VMS", "name": "HVAC?"},  # sensor/switch
-    "49": {"type": " 49", "name": "HVAC?"},  # VCE switch
     # specials
     "63": {"type": "NUL", "name": "Null Device"},
     "--": {"type": "---", "name": "No Device"},
@@ -290,11 +238,11 @@ DEVICE_TABLE = {
 # VMS includes Nuaire VMS-23HB33, VMS-23LMH23
 # What about Honeywell MT4 actuator?
 
-DEVICE_TABLE["00"] = dict(DEVICE_TABLE["04"])
-DEVICE_TABLE["00"]["type"] = "TRv"
+_OUT_DEVICE_TABLE["00"] = dict(_OUT_DEVICE_TABLE["04"])
+_OUT_DEVICE_TABLE["00"]["type"] = "TRv"
 
-DEVICE_TABLE["12"] = dict(DEVICE_TABLE["22"])
-DEVICE_TABLE["12"]["type"] = "THm"
+_OUT_DEVICE_TABLE["12"] = dict(_OUT_DEVICE_TABLE["22"])
+_OUT_DEVICE_TABLE["12"]["type"] = "THm"
 
 # Example of:
 #  - Sundial RF2 Pack 3: 23:(ST9420C), 07:(CS92), and 22:(DTS92(E))
@@ -302,7 +250,7 @@ DEVICE_TABLE["12"]["type"] = "THm"
 # HCW80 has option of being wired (normally wireless)
 # ST9420C has battery back-up (as does evohome)
 
-DEVICE_TYPES = {k: v["type"] for k, v in DEVICE_TABLE.items()}
+DEVICE_TYPES = {k: v["type"] for k, v in _OUT_DEVICE_TABLE.items()}
 DEVICE_LOOKUP = {v: k for k, v in DEVICE_TYPES.items()}
 # DEVICE_CLASSES = {v["type"]: v["name"] for _, v in DEVICE_TABLE.items()}
 
