@@ -10,13 +10,13 @@ import logging
 import re
 from datetime import timedelta as td
 from functools import lru_cache
-from typing import Any, Optional, Tuple
+from typing import Any, Optional
 
 from .address import Address
 from .exceptions import InvalidPacketError, InvalidPayloadError
 from .packet import fraction_expired
 from .parsers import PAYLOAD_PARSERS, parser_unknown
-from .ramses import CODE_IDX_COMPLEX, CODE_RQ_COMPLEX, RAMSES_CODES, RAMSES_DEVICES
+from .ramses import CODE_IDX_COMPLEX, CODE_RQ_COMPLEX, RAMSES_CODES
 
 from .const import I_, RP, RQ, W_, __dev_mode__  # noqa: F401, isort: skip
 from .const import (  # noqa: F401, isort: skip
@@ -32,6 +32,7 @@ from .const import (  # noqa: F401, isort: skip
     _000E,
     _0016,
     _0100,
+    _0150,
     _01D0,
     _01E9,
     _0404,
@@ -40,9 +41,13 @@ from .const import (  # noqa: F401, isort: skip
     _0B04,
     _1030,
     _1060,
+    _1081,
     _1090,
+    _1098,
     _10A0,
+    _10B0,
     _10E0,
+    _10E1,
     _1100,
     _1260,
     _1280,
@@ -52,9 +57,12 @@ from .const import (  # noqa: F401, isort: skip
     _12B0,
     _12C0,
     _12C8,
+    _12F0,
+    _1300,
     _1F09,
     _1F41,
     _1FC9,
+    _1FD0,
     _1FD4,
     _2249,
     _22C9,
@@ -65,6 +73,10 @@ from .const import (  # noqa: F401, isort: skip
     _2309,
     _2349,
     _2389,
+    _2400,
+    _2401,
+    _2410,
+    _2420,
     _2D49,
     _2E04,
     _30C9,
@@ -74,7 +86,11 @@ from .const import (  # noqa: F401, isort: skip
     _31D9,
     _31DA,
     _31E0,
+    _3200,
+    _3210,
     _3220,
+    _3221,
+    _3223,
     _3B00,
     _3EF0,
     _3EF1,
@@ -144,10 +160,14 @@ class Message:
                 return f"({pkt.payload[:2]})"
             return ctx
 
-        def display_name(addr: Address) -> str:  # TODO: is broken
-            # name = d.schema.get("alias") if self._gwy.config.use_aliases else None
-            name = None  # FIXME
-            return name[:20] if name else Address._friendly(addr.id)
+        def display_name(addr: Address) -> str:  # TODO: needs caching
+            name = None
+            if self._gwy._include.get(addr.id):
+                if self._gwy.config.use_aliases:
+                    name = self._gwy._include[addr.id].get("alias")
+                if not name and (klass := self._gwy._include[addr.id].get("class")):
+                    name = f"{klass}:{addr.id[3:]}"
+            return (name or Address._friendly(addr.id))[:18]  # HACK
 
         if self._str is not None:
             return self._str
@@ -283,34 +303,38 @@ class Message:
         return {index_name: self._pkt._idx}
 
     @property
-    def _expired(self) -> Tuple[bool, Optional[bool]]:
-        """Return True if the message is dated (does not require a valid payload)."""
+    def _expired(self) -> bool:
+        """Return True if the message is dated (or False otherwise)."""
 
         if self._fraction_expired is not None:
             if self._fraction_expired == self.CANT_EXPIRE:
                 return False
-            if self._fraction_expired > self.HAS_EXPIRED * 2:  # TODO: should delete?
+            if self._fraction_expired > self.HAS_EXPIRED * 2:
                 return True
 
+        prev_fraction = self._fraction_expired
+
         if self.code == _1F09 and self.verb != RQ:
             # RQs won't have remaining_seconds, RP/Ws have only partial cycle times
             self._fraction_expired = fraction_expired(
                 self._gwy._dt_now() - self.dtm,
                 td(seconds=self.payload["remaining_seconds"]),
             )
-        else:
-            self._fraction_expired = self._pkt._expired
+        else:  # self._pkt._expired can be False (doesn't expire), wont be 0
+            self._fraction_expired = self._pkt._expired or self.CANT_EXPIRE
 
-        if self._fraction_expired is False:  # treat as never expiring
-            _LOGGER.info(f"{self._pkt} # cant expire")
-            self._fraction_expired = self.CANT_EXPIRE
+        if self._fraction_expired < self.HAS_EXPIRED:
+            return False
 
-        elif self._fraction_expired > self.HAS_EXPIRED:  # TODO: should renew?
-            if any(
-                (
-                    self.code == _1F09 and self.verb != I_,
-                    self.code in (_0016, _3120, _313F),
-                )
+        # TODO: should renew?
+
+        # only log expired packets once
+        if prev_fraction is None or prev_fraction < self.HAS_EXPIRED:
+            if (
+                self.code == _1F09
+                and self.verb != I_
+                or self.code in (_0016, _3120, _313F)
+                or self._gwy._engine_state is not None  # restoring from pkt log
             ):
                 _logger = _LOGGER.info
             else:
@@ -352,8 +376,6 @@ class Message:
         try:  # parse the payload
             # TODO: only accept invalid packets to/from HGI when flag raised
             _check_msg_payload(self, self._pkt.payload)  # ? InvalidPayloadError
-            _check_msg_src(self)  # ? InvalidPacketError
-            _check_msg_dst(self)  # ? InvalidPacketError
 
             if not self._has_payload or (
                 self.verb == RQ and self.code not in CODE_RQ_COMPLEX
@@ -404,94 +426,6 @@ def re_compile_re_match(regex, string) -> bool:
     return re.compile(regex).match(string)
 
 
-# cat *.log | grep -E ' (16:|20:|29:|32:|37:|39:|44:)'         | grep -vE ' (\*|RQ|042F|1060|10E0|22F1|3120|313F) ' | grep -vE ' (1298|12A0|12C8|22F3|31D9|31DA|31E0) '^C
-# cat *.log | grep -E ' (1298|12A0|12C8|22F3|31D9|31DA|31E0) ' | grep -vE ' (RQ|30:|16:|20:|29:|32:|37:|39:|44:)'
-
-
-def _check_msg_src(msg: Message) -> None:
-    """Validate the packet's source device type against its verb/code pair.
-
-    Raise InvalidPacketError if the meta data is invalid, otherwise simply return.
-    """
-
-    #
-    #
-
-    if msg.src.type not in RAMSES_DEVICES:  # DEX, TODO: fingerprint dev class
-        if msg.code not in HVAC_ONLY_CODES:
-            raise InvalidPacketError(f"Unknown src device type: {msg.src.id}")
-        _LOGGER.warning(f"{msg._pkt} < Unknown src device type: {msg.src.id} (HVAC?)")
-        return
-
-    #
-    #
-
-    #
-    #
-
-    if msg.code not in RAMSES_DEVICES[msg.src.type]:  # DEX
-        if msg.src.type != "18":  # DEX
-            raise InvalidPacketError(f"Invalid code for {msg.src.id} to Tx: {msg.code}")
-        if msg.verb in (RQ, W_):  # DEX
-            return
-        _LOGGER.warning(f"{msg._pkt} < Invalid code for {msg.src.id} to Tx: {msg.code}")
-        return
-
-    #
-    #
-    #
-    #
-
-    #
-    # (code := RAMSES_DEVICES[msg.src.type][msg.code]) and msg.verb not in code:
-    if msg.verb not in RAMSES_DEVICES[msg.src.type][msg.code]:  # DEX
-        raise InvalidPacketError(
-            f"Invalid verb/code for {msg.src.id} to Tx: {msg.verb}/{msg.code}"
-        )
-
-
-def _check_msg_dst(msg: Message) -> None:
-    """Validate the packet's destination device type against its verb/code pair.
-
-    Raise InvalidPacketError if the meta data is invalid, otherwise simply return.
-    """
-
-    if msg.dst.type in ("--", "63"):  # or "18" in (msg.src.type, msg.dst.type):  # DEX
-        return  # TODO: HGI80s
-
-    if msg.dst.type not in RAMSES_DEVICES:  # DEX, TODO: fingerprint dev class
-        if msg.code not in HVAC_ONLY_CODES:
-            raise InvalidPacketError(f"Unknown dst device type: {msg.dst.id}")
-        _LOGGER.warning(f"{msg._pkt} < Unknown dst device type: {msg.dst.id} (HVAC?)")
-        return
-
-    if msg.verb == I_:  # TODO: not common, unless src=dst
-        return  # receiving an I isn't currently in the schema & cant yet be tested
-
-    if f"{msg.dst.type}/{msg.verb}/{msg.code}" in (f"01/{RQ}/{_3EF1}",):  # DEX
-        return  # HACK: an exception-to-the-rule that need sorting
-
-    if msg.code not in RAMSES_DEVICES[msg.dst.type]:  # NOTE: is not OK for Rx, DEX
-        if msg.dst.type != "18":  # NOTE: not (yet) needed because of 1st if, DEX
-            raise InvalidPacketError(f"Invalid code for {msg.dst.id} to Rx: {msg.code}")
-        if msg.verb == RP:  # DEX
-            return
-        _LOGGER.warning(f"{msg._pkt} < Invalid code for {msg.dst.id} to Tx: {msg.code}")
-        return
-
-    if f"{msg.verb}/{msg.code}" in (f"{W_}/{_0001}",):
-        return  # HACK: an exception-to-the-rule that need sorting
-    if f"{msg.dst.type}/{msg.verb}/{msg.code}" in (f"13/{RQ}/{_3EF0}",):  # DEX
-        return  # HACK: an exception-to-the-rule that need sorting
-
-    verb = {RQ: RP, RP: RQ, W_: I_}[msg.verb]
-    # (code := RAMSES_DEVICES[msg.dst.type][msg.code]) and verb not in code:
-    if verb not in RAMSES_DEVICES[msg.dst.type][msg.code]:  # DEX
-        raise InvalidPacketError(
-            f"Invalid verb/code for {msg.dst.id} to Rx: {msg.verb}/{msg.code}"
-        )
-
-
 def _check_msg_payload(msg: Message, payload) -> None:
     """Validate the packet's payload against its verb/code pair.
 
