@@ -34,7 +34,7 @@ from .command import (
 )
 from .const import HGI_DEVICE_ID, NON_DEVICE_ID, NUL_DEVICE_ID, __dev_mode__
 from .exceptions import InvalidPacketError
-from .helpers import dt_now
+from .helpers import dt_now  # noqa, type: ignore
 from .packet import Packet
 from .protocol import create_protocol_factory
 from .schema import SERIAL_CONFIG_SCHEMA
@@ -50,7 +50,7 @@ if DEV_MODE:  # or True:
 BLOCK_LIST = "block_list"
 KNOWN_LIST = "known_list"
 
-IS_INITIALIZED = "IS_INITIALIZED"
+IS_INITIALIZED = "is_initialized"
 IS_EVOFW3 = "is_evofw3"
 DEVICE_ID = "device_id"
 
@@ -310,8 +310,9 @@ class PacketProtocolBase(asyncio.Protocol):
         self._disable_sending = gwy.config.disable_sending
         self._evofw_flag = gwy.config.evofw_flag
 
-        if gwy.config.enforce_known_list:
-            self._exclude = []
+        self.enforce_include = gwy.config.enforce_known_list
+        if self.enforce_include:
+            self._exclude = list(gwy._exclude.keys())
             self._include = list(gwy._include.keys())
         else:
             self._exclude = list(gwy._exclude.keys())
@@ -352,8 +353,8 @@ class PacketProtocolBase(asyncio.Protocol):
         because there is a significant chance the packet is simply corrupt.
         """
 
-        for dev_id in [d for d in dict.fromkeys((src_id, dst_id))]:
-            if dev_id in self._unwanted:
+        for dev_id in dict.fromkeys((src_id, dst_id)):
+            if dev_id in self._unwanted:  # TODO: remove entries older than (say) 1w/1d
                 return
 
             if dev_id in self._exclude:
@@ -376,19 +377,19 @@ class PacketProtocolBase(asyncio.Protocol):
                         f"Allowing packets with device_id: {dev_id} (is gateway), "
                         f"configure the {KNOWN_LIST}/{BLOCK_LIST} as required"
                     )
-                    self._include.append(dev_id)  # only time include list is modified
+                self._include.append(dev_id)  # NOTE: only time include list is modified
                 continue
 
             if dev_id[:2] == "18" and self._gwy.serial_port:  # dex
-                _LOGGER.warning(
+                (_LOGGER.info if dev_id in self._exclude else _LOGGER.warning)(
                     f"Blocking packets with device_id: {dev_id} (is foreign gateway), "
                     f"configure the {KNOWN_LIST}/{BLOCK_LIST} as required"
                 )
                 self._unwanted.append(dev_id)
                 return
 
-            if self._include:
-                _LOGGER.warning(
+            if self.enforce_include:  # self._include:
+                (_LOGGER.info if dev_id in self._exclude else _LOGGER.warning)(
                     f"Blocking packets with device_id: {dev_id} (is not whitelisted), "
                     f"if required, add it to the {KNOWN_LIST}"
                 )
@@ -446,7 +447,7 @@ class PacketProtocolBase(asyncio.Protocol):
                 _LOGGER.error("%s < Cant create packet (ignoring): %s", line, exc)
             return
 
-        if pkt.src.type == "18":  # dex: should use HGI, but how?
+        if pkt.src.type == "18":  # dex: ideally should use HGI, but how?
             if self._hgi80[DEVICE_ID] is None:
                 self._hgi80[DEVICE_ID] = pkt.src.id
 
@@ -509,10 +510,6 @@ class PacketProtocolBase(asyncio.Protocol):
         if self._disable_sending:
             raise RuntimeError("Sending is disabled")
 
-        # if not self._is_wanted(cmd.src, cmd.dst):
-        #     _LOGGER.warning(
-        #     return
-
         if cmd.src.id != HGI_DEVICE_ID:
             if self._hgi80[IS_EVOFW3]:
                 _LOGGER.info(
